@@ -145,6 +145,23 @@ class LocalApiClient(BaseClient):
         ]
         return active_linked_cards
 
+    def get_linked_cards(self, reference_id: str, transaction_id: str):
+        linked_cards = self.execute(
+            method_name='GetLinkedCards',
+            arguments=[
+                self.terminal_id,
+                reference_id,
+                transaction_id,
+            ],
+        )
+        linked_cards['cards'] = [
+            {
+                key: date_time_normalize(value)
+                for (key, value) in card.items()  # noqa: WPS110
+            } for card in linked_cards['cards']
+        ]
+        return linked_cards
+
     def change_pin(
         self,
         reference_id: str,
@@ -319,3 +336,147 @@ class LocalApiClient(BaseClient):
                 transaction_id,
             ],
         )
+
+    def administrative_message(
+        self,
+        reference_id: str,
+        message_name: str,
+        transaction_id: str,
+        message_data: str = '',
+    ):
+        return self.execute(
+            method_name='AdministrativeMessage',
+            arguments=[
+                self.terminal_id,
+                reference_id,
+                message_name,
+                message_data,
+                transaction_id,
+            ],
+        )
+
+    def activate_token(
+        self,
+        reference: str,
+        card_identifier: str,
+        reason_code: str,
+        transaction_id: str,
+        comment: str = '',
+        token_unique_reference: str = '',
+        activation_code: str = '',
+    ):
+        return self.execute(
+            method_name='ActivateToken',
+            arguments=[
+                self.terminal_id,
+                reference,
+                card_identifier,
+                token_unique_reference,
+                activation_code,
+                reason_code,
+                comment,
+                transaction_id,
+            ],
+        )
+
+    def delete_token(
+        self,
+        reference: str,
+        card_identifier: str,
+        stop_reason_id: int,
+        transaction_id: str,
+        comment: str = '',
+        token_unique_reference: str = '',
+    ):
+        return self.execute(
+            method_name='DeleteToken',
+            arguments=[
+                self.terminal_id,
+                reference,
+                card_identifier,
+                token_unique_reference,
+                stop_reason_id,
+                comment,
+                transaction_id,
+            ],
+        )
+
+    def list_tokens(
+        self,
+        reference: str,
+        card_identifier: str,
+        transaction_id: str,
+    ):
+        return self.execute(
+            method_name='ListTokens',
+            arguments=[
+                self.terminal_id,
+                reference,
+                card_identifier,
+                transaction_id,
+            ],
+        )
+
+    def stop_token(
+        self,
+        reference: str,
+        card_identifier: str,
+        stop_reason_id: int,
+        transaction_id: str,
+        comment: str = '',
+        token_unique_reference: str = '',
+    ):
+        return self.execute(
+            method_name='StopToken',
+            arguments=[
+                self.terminal_id,
+                reference,
+                card_identifier,
+                token_unique_reference,
+                stop_reason_id,
+                comment,
+                transaction_id,
+            ],
+        )
+
+    def transfer_token(
+        self,
+        reference: str,
+        token_unique_reference: str,
+        old_card_identifier: str,
+        new_card_identifier: str,
+        transaction_id: str,
+    ):
+        return self.execute(
+            method_name='TransferToken',
+            arguments=[
+                self.terminal_id,
+                reference,
+                token_unique_reference,
+                old_card_identifier,
+                new_card_identifier,
+                transaction_id,
+            ],
+        )
+
+    def unstop_token(
+        self,
+        reference: str,
+        card_identifier: str,
+        unstop_reason_id: int,
+        transaction_id: str,
+        comment: str = '',
+        token_unique_reference: str = '',
+    ):
+        return self.execute(
+            method_name='UnstopToken',
+            arguments=[
+                self.terminal_id,
+                reference,
+                card_identifier,
+                token_unique_reference,
+                unstop_reason_id,
+                comment,
+                transaction_id,
+            ],
+        )
